
/*
This TSWBrowserDetect code is in part taken from http://www.quirksmode.org/js/detect.html;
available as public domain: http://www.quirksmode.org/about/copyright.html
*/
var TSWBrowserDetect = {
	init: function () {
		this.browser = this.searchString(this.dataBrowser) || "An unknown browser";
		this.version = this.searchVersion(navigator.userAgent)
			|| this.searchVersion(navigator.appVersion)
			|| "an unknown version";
		this.OS = this.searchString(this.dataOS) || "an unknown OS";
	},
	searchString: function (data) {
		for (var i=0;i<data.length;i++)	{
			var dataString = data[i].string;
			var dataProp = data[i].prop;
			this.versionSearchString = data[i].versionSearch || data[i].identity;
			if (dataString) {
				if (dataString.indexOf(data[i].subString) != -1)
					return data[i].identity;
			}
			else if (dataProp)
				return data[i].identity;
		}
	},
	searchVersion: function (dataString) {
		var index = dataString.indexOf(this.versionSearchString);
		if (index == -1) return;
		return parseFloat(dataString.substring(index+this.versionSearchString.length+1));
	},
	dataBrowser: [
		{
			string: navigator.userAgent,
			subString: "Chrome",
			identity: "Chrome"
		},
		{ 	string: navigator.userAgent,
			subString: "OmniWeb",
			versionSearch: "OmniWeb/",
			identity: "OmniWeb"
		},
		{
			string: navigator.vendor,
			subString: "Apple",
			identity: "Safari",
			versionSearch: "Version"
		},
		{
			prop: window.opera,
			identity: "Opera"
		},
		{
			string: navigator.vendor,
			subString: "iCab",
			identity: "iCab"
		},
		{
			string: navigator.vendor,
			subString: "KDE",
			identity: "Konqueror"
		},
		{
			string: navigator.userAgent,
			subString: "Firefox",
			identity: "Firefox"
		},
		{
			string: navigator.vendor,
			subString: "Camino",
			identity: "Camino"
		},
		{		// for newer Netscapes (6+)
			string: navigator.userAgent,
			subString: "Netscape",
			identity: "Netscape"
		},
		{
			string: navigator.userAgent,
			subString: "MSIE",
			identity: "Explorer",
			versionSearch: "MSIE"
		},
		{
			string: navigator.userAgent,
			subString: "Gecko",
			identity: "Mozilla",
			versionSearch: "rv"
		},
		{ 		// for older Netscapes (4-)
			string: navigator.userAgent,
			subString: "Mozilla",
			identity: "Netscape",
			versionSearch: "Mozilla"
		}
	],
	dataOS : [
		{
			string: navigator.platform,
			subString: "Win",
			identity: "Windows"
		},
		{
			string: navigator.platform,
			subString: "Mac",
			identity: "Mac"
		},
		{
			   string: navigator.userAgent,
			   subString: "iPhone",
			   identity: "iPhone/iPod"
	    },
		{
			string: navigator.platform,
			subString: "Linux",
			identity: "Linux"
		}
	]

};

//Returns true if the browser matches the specified parameters. Any of
//the parameters may be null, in which case the parameter is considered matching.
TSWBrowserDetect.browserMatches = function(browser, minVersion, maxVersion)
{
	if(browser != null && browser != this.browser)
		return false;
	if(minVersion != null && this.version < minVersion)
		return false;
	if(maxVersion != null && this.version > maxVersion)
		return false;
	return true;
};

//Returns the name for the specified property, or null if property is not supported.
//element is an optional parameter
TSWBrowserDetect.browserPropertyName = function(propName, element)
{
	var prefixes = ['Moz', 'Webkit', 'Khtml', 'O', 'Ms'];
	element = element || document.documentElement;
	var style = element.style, prefixed;

	// test standard property first
	if (typeof style[propName] == 'string') return propName;
	// capitalize
	propName = propName.charAt(0).toUpperCase() + propName.slice(1);

	// test vendor specific properties
	for (var i=0, l=prefixes.length; i<l; i++)
	{
		prefixed = prefixes[i] + propName;
		if (typeof style[prefixed] == 'string') return prefixed;
	}
	
	return null;
}

TSWBrowserDetect.init();